@@ -1,4 +1,4 @@
-#    $Id: Nominet.pm,v 1.22 2019/06/21 14:31:33 pete Exp $
+#    $Id: Nominet.pm,v 1.24 2019/07/13 15:25:03 pete Exp $
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,14 +29,13 @@ use constant EPP_XMLNS	=> 'urn:ietf:params:xml:ns:epp-1.0';
 use vars qw($Error $Code $Message);
 
 BEGIN {
-	our $VERSION = '0.03_03';
+	our $VERSION = '0.03_04';
 }
 
 # file-scoped lexicals
 my %Host      = (
 	prod => 'epp.nominet.org.uk',
 	test => 'testbed-epp.nominet.org.uk',
-	ror  => 'ror-epp.nominet.org.uk',
 	ote  => 'ote-epp.nominet.org.uk',
 );
 my $EPPVer    = '1.0';
@@ -82,7 +81,7 @@ service
 
 =head1 Description
 
-L<Nominet|http://www.nominet.org.uk/> is the organisation in charge of
+L<Nominet|https://www.nominet.uk/> is the organisation in charge of
 domain names under the .uk TLD.  Historically it used cryptographically
 signed email communications with registrars to provision domains.
 More recently (since 2010) it has instituted an EPP system
@@ -118,9 +117,8 @@ exceptions:
 defaults to 8700
 
 =item * C<host> will be set to the appropriate endpoint. Specify C<ote>
-with value 1 to connect to the OT&E endpoint, C<ror> with value 1 for
-the RoR endpoint, C<test> with value 1 for the testbed endpoint and none
-of these for the standard live endpoint.
+with value 1 to connect to the OT&E endpoint, C<test> with value 1 for
+the testbed endpoint and none of these for the standard live endpoint.
 
 =item * C<timeout> defaults to 5 (seconds).
 
@@ -181,11 +179,7 @@ sub new {
 		# Use live server
 		$params{port} = 700;
 		$params{ssl}  =   1;
-		if ($params{ror} and $params{ror} == 1) {
-			$params{host} = $Host{ror};
-		} else {
-			$params{host} = $Host{prod};
-		}
+		$params{host} = $Host{prod};
 	}
 	warn "Connecting to $params{host}:$params{port}\n" if $Debug;
 	$params{timeout}	= (int($params{timeout} || 0) > 0 ? $params{timeout} : 5);
@@ -259,7 +253,7 @@ options. Currently the only supported option is 'tag_list' which
 should be set to a true value if the user needs to use the
 L<list_tags|/List Tags>
 method. Nominet operates a number of
-L<mutually exclusive schemas|http://registrars.nominet.uk/registration-and-domain-management/schemas-and-namespace-uris>
+L<mutually exclusive schemas|https://registrars.nominet.uk/uk-namespace/registration-and-domain-management/schemas-and-namespaces/>
 so that the user needs to login again to perform different tasks. At present
 this module only supports two sets: the standard tasks and the tag list.
 
@@ -299,8 +293,7 @@ sub login {
 		push @svcs, qw/domain-nom-ext-1.2 contact-nom-ext-1.0
 			std-notifications-1.2 std-warning-1.1 std-contact-id-1.0
 			std-release-1.0 std-handshake-1.0 nom-abuse-feed-1.0
-			std-fork-1.0 std-list-1.0 std-locks-1.0 std-unrenew-1.0
-			nom-direct-rights-1.0/;
+			std-fork-1.0 std-list-1.0 std-locks-1.0 std-unrenew-1.0/;
 	}
 	# Standard schemas and extensions
 	for my $ns (@ns) {
@@ -337,17 +330,20 @@ sub login {
 =head1 Availability checks
 
 The availability checks work similarly to L<Net::EPP::Simple> except
-that they return an array with three elements. The first element is the
+that in list context they return an array with two elements.
+The first element is the
 availability indicator as before (0 if provisioned, 1 if available,
 undef on error) and the second element is the abuse counter which shows
 how many more such checks you may run. This counter is only relevant
 for check_domain and will always be undef for the other check methods.
-The third element is an indicator of the rights to register the domain.
-This is only relevant for check_domain and if the domain being checked
-is a second-level domain in which case the value will be the domain with
-the rights and undef if there are no rights.
 
-	my ($avail, $left, $rights) = $epp->check_domain ("foo.uk");
+	# List context
+	my ($avail, $left) = $epp->check_domain ("foo.uk");
+	($avail) = $epp->check_contact ("ABC123");
+	($avail) = $epp->check_host ("ns0.foo.co.uk");
+
+	# Scalar context
+	$avail = $epp->check_domain ("foo.uk");
 	$avail = $epp->check_contact ("ABC123");
 	$avail = $epp->check_host ("ns0.foo.co.uk");
 
@@ -380,21 +376,15 @@ sub _check {
 	}
 
 	my $response = $self->_send_frame ($frame) or return undef;
+	my $avail = $response->getNode($spec[1], $key)->getAttribute('avail');
+	return $avail unless wantarray;
 
 	my $extra = $response->getNode("$type-nom-ext:chkData");
 	my $count = undef;
 	$count = $extra->getAttribute('abuse-limit') if defined $extra;
 	warn "Remaining checks = $count\n" if ($Debug and defined $count);
 
-	# Rights disappear after 24/06/2019
-	my $rights = undef;
-	if ($type eq 'domain' and $identifier !~ /\..*\./) {
-		$extra  = $response->getNode("nom-direct-rights:ror") and
-			$extra  = $extra->firstChild;
-		$rights = $extra->toString if defined $extra;
-	}
-
-	return ($response->getNode($spec[1], $key)->getAttribute('avail'), $count, $rights);
+	return ($avail, $count);
 }
 
 =head1 Domain Renewal
@@ -1226,8 +1216,8 @@ sub _info {
 
 	if ($type eq 'domain') {
 		my $extra = $response->getNode('domain-nom-ext:infData');
-		my $extra2 = $response->getNode('secDNS:infData');
-		return $self->_domain_infData_to_hash($infData, $extra);
+		my $secdns = $response->getNode('secDNS:infData');
+		return $self->_domain_infData_to_hash($infData, $extra, $secdns);
 	} elsif ($type eq 'contact') {
 		# Grab disclose infdata before Net::EPP::Simple deletes it
 		my $disclose = $self->_disclose_infData_to_hash ($infData);
@@ -1242,7 +1232,7 @@ sub _info {
 }
 
 sub _domain_infData_to_hash {
-	my ($self, $infData, $extra) = @_;
+	my ($self, $infData, $extra, $secdns) = @_;
 
 	my $hash = $self->_node_to_hash ($infData, ['registrant',
 		'clID', 'crID', 'crDate', 'exDate', 'name', 'roid']);
@@ -1255,6 +1245,13 @@ sub _domain_infData_to_hash {
 		$hash->{$_} = $extrahash->{$_};
 	}
 
+	if ($secdns) {
+		my $dsObjs = $secdns->nonBlankChildNodes;
+		while (my $dsObj = $dsObjs->shift) {
+			push @{$hash->{secDNS}}, $self->_node_to_hash ($dsObj);
+		}
+	}
+
 	my $hostObjs = $infData->getElementsByLocalName('hostObj');
 	while (my $hostObj = $hostObjs->shift) {
 		push(@{$hash->{ns}}, $hostObj->textContent);
@@ -1684,6 +1681,8 @@ sub _send_frame {
 
 =head1 TODO
 
+=encoding utf8
+
 =over
 
 =item * The poll, fork, handshake, lock and reseller operations
@@ -1700,12 +1699,12 @@ are not yet supported.
 =item * L<Net::EPP::Simple>
 
 =item * Nominet's L<EPP
-Documentation|http://registrars.nominet.org.uk/registration-and-domain-management/registrar-systems/epp>
+Documentation|https://registrars.nominet.uk/uk-namespace/registration-and-domain-management/registration-systems/epp/>
 
-=item * The EPP RFCs: L<RFC 5730|http://tools.ietf.org/html/rfc5730>, 
-L<RFC 5731|http://tools.ietf.org/html/rfc5731>,
-L<RFC 5732|http://tools.ietf.org/html/rfc5732> and
-L<RFC 5733|http://tools.ietf.org/html/rfc5733>.
+=item * The EPP RFCs: L<RFC 5730|https://tools.ietf.org/html/rfc5730>, 
+L<RFC 5731|https://tools.ietf.org/html/rfc5731>,
+L<RFC 5732|https://tools.ietf.org/html/rfc5732> and
+L<RFC 5733|https://tools.ietf.org/html/rfc5733>.
 
 =back
 
@@ -1715,7 +1714,7 @@ Pete Houston <cpan@openstrike.co.uk>
 
 =head1 Licence
 
-This software is copyright (c) 2013-2017 by Pete Houston. It is released
+This software is copyright © 2013-2019 by Pete Houston. It is released
 under the Artistic Licence (version 2) and the
 GNU General Public Licence (version 2).
 
